@@ -1,6 +1,6 @@
 /* Generic bitsets.
 
-   Copyright (C) 2002-2004, 2009-2015, 2018-2020 Free Software Foundation, Inc.
+   Copyright (C) 2002-2004, 2009-2015, 2018-2021 Free Software Foundation, Inc.
 
    Contributed by Michael Hayes (m.hayes@elec.canterbury.ac.nz).
 
@@ -96,6 +96,9 @@ typedef struct
 } bitset_iterator;
 
 
+/* Free bitset.  Do nothing if NULL.  */
+void bitset_free (bitset);
+
 /* Return bytes required for bitset of desired type and size.  */
 size_t bitset_bytes (enum bitset_type, bitset_bindex);
 
@@ -107,21 +110,21 @@ bitset bitset_init (bitset, bitset_bindex, enum bitset_type);
 enum bitset_type bitset_type_choose (bitset_bindex, bitset_attrs);
 
 /* Create a bitset of desired type and size.  The bitset is zeroed.  */
-bitset bitset_alloc (bitset_bindex, enum bitset_type);
-
-/* Free bitset.  Do nothing if NULL.  */
-void bitset_free (bitset);
-
-/* Create a bitset of desired type and size using an obstack.  The
-   bitset is zeroed.  */
-bitset bitset_obstack_alloc (struct obstack *bobstack,
-                             bitset_bindex, enum bitset_type);
+bitset bitset_alloc (bitset_bindex, enum bitset_type)
+  _GL_ATTRIBUTE_DEALLOC (bitset_free, 1);
 
 /* Free bitset allocated on obstack.  Do nothing if NULL.  */
 void bitset_obstack_free (bitset);
 
+/* Create a bitset of desired type and size using an obstack.  The
+   bitset is zeroed.  */
+bitset bitset_obstack_alloc (struct obstack *bobstack,
+                             bitset_bindex, enum bitset_type)
+  _GL_ATTRIBUTE_DEALLOC (bitset_obstack_free, 1);
+
 /* Create a bitset of desired size and attributes.  The bitset is zeroed.  */
-bitset bitset_create (bitset_bindex, bitset_attrs);
+bitset bitset_create (bitset_bindex, bitset_attrs)
+  _GL_ATTRIBUTE_DEALLOC (bitset_free, 1);
 
 /* Return bitset type.  */
 enum bitset_type bitset_type_get (bitset);
@@ -282,17 +285,21 @@ bitset_test (bitset bset, bitset_bindex bitno)
 /* Return true if both bitsets are of the same type and size.  */
 bool bitset_compatible_p (bitset bset1, bitset bset2);
 
-/* Find next set bit from the given bit index.  */
-bitset_bindex bitset_next (bitset, bitset_bindex);
+/* Find next bit set in SRC starting from and including BITNO.
+   Return BITSET_BINDEX_MAX if SRC empty.  */
+bitset_bindex bitset_next (bitset src, bitset_bindex bitno);
 
-/* Find previous set bit from the given bit index.  */
-bitset_bindex bitset_prev (bitset, bitset_bindex);
+/* Find previous bit set in SRC starting from and including BITNO.
+   Return BITSET_BINDEX_MAX if SRC empty.  */
+bitset_bindex bitset_prev (bitset src, bitset_bindex bitno);
 
-/* Find first set bit.  */
-bitset_bindex bitset_first (bitset);
+/* Find first set bit.
+   Return BITSET_BINDEX_MAX if SRC empty.  */
+bitset_bindex bitset_first (bitset src);
 
-/* Find last set bit.  */
-bitset_bindex bitset_last (bitset);
+/* Find last set bit.
+   Return BITSET_BINDEX_MAX if SRC empty.  */
+bitset_bindex bitset_last (bitset src);
 
 /* Return nonzero if this is the only set bit.  */
 bool bitset_only_set_p (bitset, bitset_bindex);
