@@ -1,6 +1,6 @@
 /* Lists of symbols for Bison
 
-   Copyright (C) 2002, 2005-2007, 2009-2015, 2018-2019 Free Software
+   Copyright (C) 2002, 2005-2007, 2009-2015, 2018-2021 Free Software
    Foundation, Inc.
 
    This file is part of Bison, the GNU Compiler Compiler.
@@ -16,7 +16,7 @@
    GNU General Public License for more details.
 
    You should have received a copy of the GNU General Public License
-   along with this program.  If not, see <http://www.gnu.org/licenses/>.  */
+   along with this program.  If not, see <https://www.gnu.org/licenses/>.  */
 
 #ifndef SYMLIST_H_
 # define SYMLIST_H_
@@ -50,7 +50,6 @@ typedef struct symbol_list
      */
     semantic_type *sem_type;
   } content;
-  location location;
 
   /* Named reference. */
   named_ref *named_ref;
@@ -74,6 +73,9 @@ typedef struct symbol_list
   | when several RHSs are bound to a single lhs via "|").         |
   `--------------------------------------------------------------*/
 
+  /* Location of the RHS. */
+  location rhs_loc;
+
   /* Precedence/associativity.  */
   symbol *ruleprec;
 
@@ -82,13 +84,13 @@ typedef struct symbol_list
   code_props action_props;
 
   /* The location of the first %empty for this rule, or \a
-     empty_location.  */
+     empty_loc.  */
   location percent_empty_loc;
 
   int dprec;
-  location dprec_location;
+  location dprec_loc;
   int merger;
-  location merger_declaration_location;
+  location merger_declaration_loc;
 
   /* Counts of the number of expected conflicts for this rule, or -1 if none
      given. */
@@ -108,8 +110,10 @@ symbol_list *symbol_list_type_new (uniqstr type_name, location loc);
 
 /** Assign the type \c type_name to all the members of \c syms.
  ** \returns \c syms */
-symbol_list *symbol_list_type_set (symbol_list *syms,
-                                   uniqstr type_name, location loc);
+symbol_list *symbol_list_type_set (symbol_list *syms, uniqstr type_name);
+
+/** Find a symbol with the same content as \c sym within \c syms.  */
+symbol_list *symbol_list_find_symbol (symbol_list *syms, const symbol *sym);
 
 /** Print this list.
 
@@ -120,6 +124,9 @@ void symbol_list_syms_print (const symbol_list *l, FILE *f);
 /** Prepend \c node to \c list.  */
 symbol_list *symbol_list_prepend (symbol_list *list, symbol_list *node);
 
+/** The last node of this list. */
+symbol_list *symbol_list_last (symbol_list *list);
+
 /** Append \c node to \c list.  */
 symbol_list *symbol_list_append (symbol_list *list, symbol_list *node);
 
@@ -135,11 +142,11 @@ int symbol_list_length (symbol_list const *l);
  **/
 symbol_list *symbol_list_n_get (symbol_list *l, int n);
 
-/* Get the data type (alternative in the union) of the value for
-   symbol N in rule RULE.  */
+/** Get the data type (alternative in the union) of the value for
+    symbol N in rule RULE.  */
 uniqstr symbol_list_n_type_name_get (symbol_list *l, int n);
 
-/* Check whether the node is a border element of a rule. */
+/** Check whether the node is a border element of a rule. */
 bool symbol_list_null (symbol_list *node);
 
 /** Set the \c \%destructor or \c \%printer for \c node as \c cprops.  */
